"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_path_1 = require("node:path");
const node_fs_1 = require("node:fs");
const plugin_vue_1 = __importDefault(require("@vitejs/plugin-vue"));
const plugin_vue_jsx_1 = __importDefault(require("@vitejs/plugin-vue-jsx"));
const vite_svg_loader_1 = __importDefault(require("vite-svg-loader"));
const plugin_terser_1 = __importDefault(require("@rollup/plugin-terser"));
const vite_plugin_dts_1 = __importDefault(require("vite-plugin-dts"));
const identifierHelpers_1 = require("../utils/identifierHelpers");
//
const pkg = JSON.parse((0, node_fs_1.readFileSync)((0, node_path_1.resolve)(process.cwd(), 'package.json'), 'utf-8'));
const externalPkgs = [
    'vue',
    '@arco-design/web-vue',
    '@arco-design/web-vue/es/icon',
].concat(Object.keys(pkg.dependencies || {}), Object.keys(pkg.peerDependencies || {}));
const external = (id) => externalPkgs.some((p) => p === id || id.startsWith(`${p}/`));
let globalsPkg = externalPkgs.reduce((val, v, index) => {
    // copy 自 rollup
    const vPkgName = (0, identifierHelpers_1.makeLegal)(v.split(/[/\\]/).pop());
    return Object.assign(Object.assign({}, val), { [v]: vPkgName });
}, {});
const getConfig = ({ input, name, }) => {
    const inputDir = input.split('/').slice(0, -1).join('/');
    const dtsExclude = [
        `${inputDir}/test/**`,
        `${inputDir}/__test__/**`,
        `${inputDir}/__demo__/**`,
        `${inputDir}/demo/**`,
        `${inputDir}/style/**`,
    ];
    return {
        mode: 'production',
        esbuild: {
            drop: ['debugger'],
            pure: ['console.log'],
        },
        build: {
            target: 'modules',
            outDir: 'dist',
            emptyOutDir: true,
            minify: false,
            rollupOptions: {
                external,
                output: [
                    {
                        format: 'module',
                        sourcemap: false,
                        entryFileNames: 'index.esm.js',
                    },
                    {
                        format: 'commonjs',
                        sourcemap: false,
                        exports: "named",
                        entryFileNames: 'index.cjs.js',
                    },
                    {
                        format: 'umd',
                        entryFileNames: 'index.min.js',
                        sourcemap: false,
                        exports: "named",
                        name,
                        esModule: false,
                        globals: Object.assign(Object.assign({}, globalsPkg), { 'vue': 'Vue', '@arco-design/web-vue': 'ArcoVue', '@arco-design/web-vue/es/icon': 'ArcoVueIcon' }),
                        // todo: terser 声明错误 该如何解决 或者增加其他方案
                        plugins: [(0, plugin_terser_1.default)()],
                    },
                ],
            },
            lib: {
                entry: input,
                // formats: ['es'],
            },
        },
        plugins: [
            (0, plugin_vue_1.default)(),
            (0, plugin_vue_jsx_1.default)(),
            (0, vite_svg_loader_1.default)(),
            (0, vite_plugin_dts_1.default)({
                include: [inputDir],
                exclude: dtsExclude
            }),
        ],
    };
};
exports.default = getConfig;
//# sourceMappingURL=vite.material.prod.js.map