"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.build = void 0;
const node_path_1 = __importDefault(require("node:path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const ts_morph_1 = require("ts-morph");
const glob_1 = require("glob");
const compiler_sfc_1 = require("@vue/compiler-sfc");
function build(input, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const root = process.cwd();
        const tsConfigFilePath = fs_extra_1.default.existsSync('tsconfig.json')
            ? 'tsconfig.json'
            : undefined;
        const project = new ts_morph_1.Project({
            compilerOptions: {
                allowJs: true,
                declaration: true,
                emitDeclarationOnly: true,
                strict: true,
                target: ts_morph_1.ScriptTarget.ES2015,
                moduleResolution: ts_morph_1.ModuleResolutionKind.NodeJs,
                isolatedModules: true,
                esModuleInterop: true,
                skipLibCheck: true,
                jsx: 1,
            },
            tsConfigFilePath,
            skipAddingFilesFromTsConfig: true,
        });
        const isComponents = /^components/.test(input);
        if (isComponents) {
            project.compilerOptions.set({
                rootDir: node_path_1.default.resolve(root, 'components'),
            });
        }
        if (options === null || options === void 0 ? void 0 : options.outDir) {
            project.compilerOptions.set({
                outDir: node_path_1.default.resolve(root, options.outDir),
            });
        }
        const files = (0, glob_1.globSync)(input, {
            ignore: /components\/icon/.test(input)
                ? ['**/__test__/*', '**/__demo__/*']
                : ['**/__test__/*', '**/__demo__/*', 'components/icon/**/*'],
        });
        const sourceFiles = [];
        yield Promise.all(files.map((file) => __awaiter(this, void 0, void 0, function* () {
            const content = yield fs_extra_1.default.promises.readFile(node_path_1.default.resolve(root, file), 'utf8');
            if (file.endsWith('.vue')) {
                const sfc = (0, compiler_sfc_1.parse)(content);
                const { script, scriptSetup } = sfc.descriptor;
                if (script || scriptSetup) {
                    let scriptContent = '';
                    let isTSX = false;
                    if (script && script.content) {
                        scriptContent += script.content;
                        if (script.lang === 'tsx')
                            isTSX = true;
                    }
                    const sourceFile = project.createSourceFile(node_path_1.default.relative(root, file).replace('.vue', isTSX ? '.tsx' : '.ts'), scriptContent);
                    if (sourceFile) {
                        removeVueSpecifier(sourceFile);
                        sourceFiles.push(sourceFile);
                    }
                }
            }
            else {
                const sourceFile = project.createSourceFile(node_path_1.default.relative(root, file), content, {
                    overwrite: true,
                });
                if (sourceFile) {
                    removeVueSpecifier(sourceFile);
                    sourceFiles.push(sourceFile);
                }
            }
        })));
        try {
            yield Promise.all(sourceFiles.map((sourceFile) => __awaiter(this, void 0, void 0, function* () {
                // eslint-disable-next-line no-console
                console.log(`Transform start: ${sourceFile.getFilePath()}`);
                const diagnostics = sourceFile.getPreEmitDiagnostics();
                // eslint-disable-next-line no-console
                console.log(project.formatDiagnosticsWithColorAndContext(diagnostics));
                const emitOutput = sourceFile.getEmitOutput();
                const outputFiles = emitOutput.getOutputFiles();
                yield Promise.all(outputFiles.map((outputFile) => __awaiter(this, void 0, void 0, function* () {
                    const filepath = outputFile.getFilePath();
                    yield fs_extra_1.default.ensureDir(node_path_1.default.dirname(filepath));
                    yield fs_extra_1.default.writeFile(filepath, outputFile.getText(), 'utf8');
                    // eslint-disable-next-line no-console
                    console.log(`Emitted ${filepath}`);
                })));
            })));
        }
        catch (_a) { }
    });
}
exports.build = build;
const removeVueSpecifier = (sourceFile) => {
    const imports = sourceFile.getImportDeclarations();
    imports.forEach((item) => {
        const specifier = item.getModuleSpecifierValue();
        const ext = node_path_1.default.extname(specifier);
        if (ext === '.vue') {
            item.setModuleSpecifier(specifier.replace('.vue', ''));
        }
    });
};
exports.default = build;
//# sourceMappingURL=index.js.map